# Stubs for mersad.classical.affine_cipher (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

# Python Standard Library
from typing import Tuple
from typing import Union

# Mersad Library
from mersad.util.base_class import MersadClassicalBase

class AffineCipher(MersadClassicalBase):
    @staticmethod
    def _translator(text: str, **kwargs: Union[int, str, bool]) -> str: ...

def affine_cipher_translator(text: str, **kwargs: Union[int, str, bool]) -> str: ...
def _get_key_parts(key: int, sequence_length: int) -> Tuple[int, int]: ...
def _check_keys(key_a: int, key_b: int, sequence_length: int) -> None: ...
